---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---

## Describe the Bug

A clear and concise description of what the bug is.

## To Reproduce

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

## Expected Behavior

A clear and concise description of what you expected to happen.

## Screenshots

If applicable, add screenshots to help explain your problem.

## Runtime Information

Please complete the following information:

- OS: [e.g. `Ubuntu`]
- OS Version: [e.g. `20.04`]
- Python Implementation [e.g. `CPython`, `PyPy`]
- Python Version [e.g. `3.9`]

## Additional Context

Add any other context about the problem here.
